# Cybrex AI

Cybrex AI integrates several strategies to use AI for facilitating navigation through science. Shortly, Cybrex accept your query, retrieve scholarly publications and books from STC and answer your query using AI and collected documents.

More technical description:
- IPFS is utilized to access the Standard Template Construct (STC).
- STC provides the raw documents for Cybrex.
- Embedding Model (OpenAI or free Instructor-XL) constructs embeddings for these documents and Cybrex stores these embeddings locally in the Chroma database.
- These embeddings are then used to filter relevant documents before they are sent to LLM (Open AI, WizardLM or any other one) for Q&A and summarization.

## Install

You should have [installed IPFS](http://standard-template-construct.org/#/help/install-ipfs)

```bash
pip install cybrex
```

Upon its initial launch, `cybrex` will create a `~/.cybrex` directory containing a `config.yaml` file and a `chroma` directory.
You can edit the config file to point to different IPFS addresses.

## Usage

**Attention!** STC does not contain every book or publication in the world. We are constantly increasing coverage but there is still a lot to do.
STC contains metadata for the most of the items, but `links` or `content` fields may be absent.

```console
# Set your OpenAI key
export OPENAI_API_KEY=...

# (Optional) Launch Summa search engine, then you will not have to wait bootstrapping every time.
# It will take a time!
# If you decided to launch it, switch to another Terminal window
geck --ipfs-http-base-url 127.0.0.1:8080 - serve

# Summarize a document
cybrex - sum-doc --field doi --value 10.1155/2022/7138756

Document: doi:10.1155/2022/7138756
Summarization: Resveratrol is a natural compound found in various plants and has been studied for 
its anti-inflammatory and antiviral properties. Resveratrol has been shown to regulate miR-223-3p/NLRP3 
pathways, inhibit downstream caspase-1 activation, reduce the expression of chemokines, and decrease 
the levels of calcium strength, pro-inflammatory cytokines, and MDA in an acute bacterial meningitis model. 
It can also regulate the PI3K/Akt/mTOR signaling pathway, reduce NF-κB/p65 and pro-inflammatory cytokines, 
and increase nitric oxide, sialic acid, gastric tissue, and vitamin C concentrations. Resveratrol has been 
found to inhibit viral replication and have antiviral activity against Zika Virus, Pseudorabies virus, 
and HSV-1. The exact mechanisms of action of resveratrol are still not fully understood, but it is believed 
to activate the host's immune defences, affect the TLRs/NF-κB signalling pathway, and directly inhibit 
viral gene expression.

# Question a document
cybrex - chat-doc --field doi --value 10.1155/2022/7138756 \
  --question "What is the antivirus effect of resveratrol?"

Q: What is the antivirus effect of resveratrol?
A: Resveratrol has been found to have antiviral effects, primarily through its ability to inhibit viral
entry and replication. It has been reported to inhibit the replication of multiple viruses, including
human immunodeficiency virus (HIV), herpes simplex virus (HSV), hepatitis C virus (HCV), and
Zika virus (ZIKV). Resveratrol appears to block the activities of the TIR-domain-containing
adapter-inducing interferon-β (TRIF) complex, suggesting that resveratrol would also inhibit NF-κB
transcription induced by TRIF. Additionally, it has been reported to reduce the activity of respiratory
syncytial virus (RSV) and to stimulate the secretion of higher levels of TNF-α, promoting cell death
and RSV clearance.

# Question enitre science
cybrex - chat-sci --question "What is the antivirus effect of resveratrol?" --n-results 15 --n-summa-documents 40

Q: What is the antivirus effect of resveratrol?
A: Resveratrol has been found to possess antiviral activity against a variety of viruses, including herpes simplex virus, human immunodeficiency virus, and hepatitis C virus. It has been shown to inhibit the replication of several viruses, including HIV, herpes simplex virus, and influenza virus, and to regulate TLR3 expression, thus affecting the recruitment of downstream related factors and finally affecting the regulation process of related signal pathways. It has also been studied for its antiviral activity against Reoviridae, and for its potential to inhibit Zika virus cytopathy effect. It has been active against Epstein virus, rotavirus, and vesicular stomatitis virus, and has been reported to alleviate virus-induced reproductive failure and to promote RSV clearance in the body more quickly.
Sources:
 - 10.1155/2022/7138756: The Antiviral Activity of Resveratrol
 - 10.1155/2022/7138756: Antiviral Mechanisms of Resveratrol
 - 10.1155/2022/7138756: The antiviral effects of resveratrol are well demonstrated. Currently, studies on the antiviral mechanism of resveratrol mainly focus on two points.On the one hand, resveratrol possesses the ability to activate the host's immune defenses, turning on a complex network of bodies to fight or eliminate incoming viruses. NF-κB belongs to a family of inducible nuclear transcription factors, which regulates a wide array of genes involved in various processes of antiviral activity, inflammatory, and immune response . Meanwhile, it is noteworthy that Toll-like receptors (TLRs) are located upstream of the NF-κB signaling pathway and are responsible for induction of antiviral innate immune responses by recognizing virus infection, which leads to the production of proinflammatory cytokines, chemokines, and interferons . Thus, the TLRs/NF-κB pathway has been extensively studied during viral infection. Likewise, most research on antiviral drugs has focused on this pathway. Resveratrol regulated TLR3 expression, thus affecting the recruitment of downstream related factors and finally affecting the regulation process of related signal pathways. Moreover, resveratrol inhibits PRV by inhibiting the IκBα degradation induced by PRV infection, thereby inhibiting the activation of the NF-κB cell signaling pathway, and subsequently inhibiting the transcription of viral genes, protein and DNA synthesis, and virion production . Thus, the TLRs/NF-κB signaling pathway plays a crucial role in the antiviral process of resveratrol. On the other hand, resveratrol also has the ability to inhibit the production of virions by directly inhibiting the expression of key viral genes or by binding to key enzymes and proteins that disrupt the viral replication cycle. In this case, resveratrol could possess antiviral activities against ZIKV NS2B 18 NS3 and helicase 3 . Overall, the antiviral mechanisms of resveratrol are diverse. We have summarized many studies and found that most of them focus on the effects of resveratrol on host signal pathways and
 - 10.1155/2022/7138756: Summary and Perspectives
   Active studies and many published articles have shed light on resveratrol's potential role in the treatment of a variety of diseases, particularly anti-inflammation and antivirus. In this review, we tried to summarize the anti-inflammatory and antiviral mechanisms of resveratrol. After reviewing many literatures, we concluded that the anti-inflammatory and antiviral effects of resveratrol involve the NF-κB signaling pathway. When inflammation occurs, resveratrol can regulate the cascade reaction of NF-κB signals, blocking the secretion of inflammatory factors, reducing the occurrence of inflammation, and enabling host cells to develop immune resistance to eliminate the virus. Therefore, the NF-κB signaling pathway is the key way for resveratrol to exert anti-inflammatory and antiviral effects.Therefore, future research should pay attention to two aspects: first, the anti-inflammatory and antiviral mechanisms of resveratrol can be traced back to related signaling pathways or upstream of NF-κB; second, resveratrol has limited clinical research data, so clinical trials can be strengthened to provide support for the application of resveratrol.
 - 10.1155/2022/7138756: antiviral activities against ZIKV NS2B 18 NS3 and helicase 3 . Overall, the antiviral mechanisms of resveratrol are diverse. We have summarized many studies and found that most of them focus on the effects of resveratrol on host signal pathways and key genes and proteins of viruses (Figure ).
 - 10.3390/cosmetics10030068: Antimicrobial
   Resveratrol has played a significant role as an antibacterial, antiviral, antifungal, and antiparasitic compound. Recently, this compound exhibited its usage both on its own and with antibiotics. At a sublethal concentration, RES can inhibit the virulent effect of pathogenic bacteria and can pave an inhibition in biofilm. The antioxidant effect of RES makes it an ideal candidate against many topical agents. Trans-RES, an isoform of RES, has been identified as a phytoalexin, and its minimum inhibitory concentration (MIC) is active against a broad range of microorganisms.
   Antibacterial
   Resveratrol has been studied profoundly for its antibacterial activity. For a limited number of bacterial species, RES exhibits a MIC of less than 100 µg/mL. MIC ranged between 100 and 200 µg/mL for gram-positive pathogenic bacteria and less than 200 µg/mL for gram-negative bacteria, . The main mechanism that has been studied in the case of gram-negative bacteria is the lower penetration power of RES and, subsequently, expulsion due to the efflux system. A similar mechanism was also supported by showing that the presence of RES exhibits a decline in growth, whereas in the case of gram-positive bacteria, there was a halt in growth. Resveratrol exhibits the binding of adenosine tri-phosphate synthase in facultative aerobic bacteria, and also activates DNA fragmentation, as well as the stress response, in E. coli . Several studies related to the bacteriostatic ability of RES, rather than bactericidal effects . The action of RES also led to changes in the morphology of the bacteria, activating SOD and subsequently inhibiting the cell . In an experimental culture utilizing E. coli and Staphylococcus as a model, with RES in the culture medium along with antimicrobials, ROS levels were reduced to sub-lethal in the mutagenic culture. Meanwhile, in the absence of RES, the ROS levels became elevated to their maximum levels, thereby predicting the role of antioxidants in the antimicrobial species .
   Antiviral
 - 10.3390/cosmetics10030068: Antiviral
   The specific potential antiviral activity of RES has been studied in several viruses, such as the major family Reoviridae. A study with Caco-2 cells was incubated with different varying concentrations of RES ranging between 20 and 80 µg/mL. This protocol was utilized with different incubation times. The cytotoxicity assays in this study exhibited a significant decline in the concentration of RES, suggesting that RES was highly effective in inhibiting Reoviridae infection by blocking the viral protein expressions and genomic expressions.The potential active interaction of Zika virus with natural compounds such as RES may play a significant role in intercellular signaling and inhibit the Zika virus cytopathy effect. A dose-dependent inhibition is the usual trend, and the mechanism involves inhibitory activity of pathways such as NF-kB, activator protein-1, protein synthesis inhibition, and a decrease in ROS production. During viral infection, a consequent regulatory response is an inflammation that can act as tumor development and proliferation . Resveratrol has been active against Epstein virus, rotavirus, and vesicular stomatitis virus, and leads to a mechanistic role in blocking protein synthesis, decreasing the level of ROS, thereby inducing activation of transcription factors and, thus, affecting replication . It has been reported that low doses of RES can inhibit or even block HIV infection by causing interference in the reverse transcription process .
   Antifungal
 - 10.1155/2022/7138756: focus on the dose of resveratrol, and there are limited reports on the antiviral mechanism.4.1.3. Pseudorabies Virus. Pseudorabies virus (PRV) is a herpesvirus of swine, a member of the Alphaherpesvirinae subfamily, and the causative agent of Aujeszky ' s disease (AD) in swine, causing respiratory, neurological, and reproductive symptoms. The infection of PRV in pigs typically starts in the nasal mucosa after viral particles infect sensory neuronal cells. Through retrograde neuronal transport, viral particles travel toward the trigeminal ganglia and olfactory bulb . PRV is always fatal in newborn piglets and often accompanied by neurological symptoms, leading to miscarriage and mummified fetuses in pregnant sows . Due to the emergence of mutant strains, the protection of vaccines has become ineffective. However, several studies have shown that resveratrol has anti-PRV activity. In vitro, Mediators of Inflammation resveratrol potently suppressed PRV replication in a dosedependent manner, with IC 50 of 17.17 μM. The inhibitory effect of resveratrol on PRV-induced cell death and gene expression may be due to its ability to inhibit the degradation of IκB kinase . The NF-κB pathway is known to integrate signaling associated with very diverse intra-and extracellular stressors, including virus infections, and triggers a proinflammatory response through the expression of NF-κB-regulated genes . Indeed, PRV infection continuously activates NF-κB, which regulates the expression of host-related inflammatory factors. Hence, NF-κB may be the key to host resistance to PRV . Additionally, in an animal study, it has been reported that resveratrol can relieve inflammation, reduce pathological changes, and enhance immunity in PRVinfected piglets . PRV infection causes stillbirth and miscarriage, resulting in poor growth of the offspring. Resveratrol treatment alleviates virus-induced reproductive failure and restores serum progesterone levels . . Additionally, resveratrol appears to block the activities of the
 - 10.1155/2022/7138756: causes stillbirth and miscarriage, resulting in poor growth of the offspring. Resveratrol treatment alleviates virus-induced reproductive failure and restores serum progesterone levels . . Additionally, resveratrol appears to block the activities of the TIR-domain-containing adapterinducing interferon-β (TRIF) complex, suggesting that resveratrol would also inhibit NF-κB transcription induced by TRIF . A review had summarized that resveratrol also reduced the activity of respiratory syncytial virus and inhibited the Toll/IL-1 receptor domain-containing adaptor inducing β interferon (TRIF) expression through upregulating sterile α and armadillo motif protein (SARM) . Moreover, resveratrol, as a SIRT-1 agonist, inhibits the replication of RSV in human bronchial epithelial cells and stimulates the secretion of higher levels of TNF-α, thereby promoting cell death. In addition, resveratrol also promotes cellular defense systems and apoptosis, which means it is possible to promote RSV clearance in the body more quickly .
 - 10.3390/metabo12060478: 2 of 13 protein kinase (AMPK) and Sirtuin1 , i.e., proteins associated with lipids metabolism, ATP production, and overall regulation of cellular defense, including the cell cycle arrest in stress conditions . Researchers also report the ability of resveratrol to increase the expression of NO synthase (eNOS), which results in vasodilation, reduction of hypoxia, and blood pressure . suggest that the protective effect of resveratrol paradoxically results from its toxic effect on cells: exposure to low doses leads to the acquisition of stress-induced resilience resulting in the increased efficiency of self-repair mechanisms and overall improvement in health and longevity . Such a statement is consistent with reports suggesting that resveratrol may act in hormesis. Lower doses (associated with oral intake) have beneficial effects, but at higher doses (which are achievable only in in vitro studies because of its pharmacokinetics) resveratrol displays toxic effects. Such mechanisms of action may be related to its action as a topoisomerase II poison .
   Resveratrol Is a Radioprotective Compound
 - 10.1139/h09-115: Introduction
   Resveratrol, 3,5,4'-trihydroxy-trans-stilbene (Fig. ), a well-known stilbene class of polyphenolic compound, naturally occurs in grapes and berries. It is a phytoalexin that is produced in response to infections in plants, and, thus, acts as a natural antibiotic. It is also synthesized in response to some environmental stresses, like climate changes and ultraviolet light . Accumulating evidence demonstrates that resveratrol exerts several beneficial health effects in humans and experimental animal models .Aerobic cells produce reactive oxygen species (ROS) as a by-product of their metabolic processes. ROS may induce oxidative stress and cause damage to all types of molecules . Several defense mechanisms have evolved in living organisms to limit the levels of ROS and the damage they inflict. Endogenous antioxidant enzymes, such as catalase, superoxide dismutase, and glutathione peroxidase, are included among them .There is overwhelming evidence to suggest that nutritional sources of antioxidants, such as fruits, vegetables, tea, and wine, attenuate tissue damage caused by oxidative challenges . Polyphenolic compounds, abundant in these nutritional sources, could play a major role in enhancing the activity of the antioxidant system .During the past couple of years, several in vivo and in vitro studies have focused on various biological effects of resveratrol. Growing evidence suggests that resveratrol may play an important role in the prevention of human diseases, such as cancer, cardiovascular diseases, diabetes, and Alzheimer's disease . Many of the biological actions of this polyphenol have been attributed to its antioxidant properties . This work was undertaken to evaluate the protective effects of trans-resveratrol on lipid peroxidation and membrane protein carbonyl groups, which are important markers of oxidative stress, in human erythrocytes subjected to in vitro oxidative stress.
   Materials and methods
   Collection of blood, isolation of erythrocytes, preparation of red cell ghosts
 - 10.1016/j.nutos.2022.01.008: also help prevent radiation damage and stimulation of cytotoxic drugs by reducing oxidative stress and rearranging the expression of survival proteins. As a result, resveratrol can be used in chemotherapy to protect normal cells to reduce side effects. Specific molecular mechanisms and signaling pathways involved in the antitumor effect of resveratrol include: regulation of activation of the enzyme system of mitochondrial cascade and caspase; upregulation of cyclin-dependent kinase inhibitors, tumor suppressor genes, and cytokines. Decreased expression of survival proteins associated with chemical resistance, including survivin, cFLIP, cIAPs, and anti-apoptotic proteins (Bcl-2 and Bcl-XL); Activation of adenosine 5 0 -activated protein kinase Monophosphate (AMPK) and MAPK inhibition, phosphoinositide 3-kinase (PI3K)/Akt, PKC, EGFR kinase, nuclear factor kB (NF-kB), activating protein 1 (AP-1), HIF-1, and signal transducer and activator of transcription 3 (STAT3) .
 - 10.1093/toxres/tfad021: and antiaging. To improve the pharmacokinetic properties of the respiratory syncytial virus, various methods and different synthetic derivatives have been developed. Resveratrol also revealed anti-inf lammatory, anticatabolic, antiapoptotic, and antioxidant properties in various joint cell types (such as chondrocytes and synovial cells) and in T and B immunomodulatory specific lymphocytes. Bakheet Saleh A et al. demonstrated that resveratrol could reduce the production and expression of the CCR and C-X-C motif chemokine receptor (CXCR) in CD4+ T cells, in the spleen and brain tissues. The mechanism of action of resveratrol suggested that resveratrol could regulate unbalanced endocrine, apoptosis, and oxidative stress. Resveratrol proved to be a strong AhR competitive antagonist (IC50 6 μM), which could inhibit the effects related to AhR activation. Resveratrol has been reported to participate in various signal pathways, such as TLRs, NF-κB, and the COX-2 signaling pathway. Resveratrol improved neuroimmune dysregulation by inhibiting neuronal Toll-like receptors and COX-2 signaling in BTBR T + Itpr3 tf/ J mice. Resveratrol ameliorated the dysregulation of Th1, Th2, Th17, and T regulatory cell-related transcription factor signaling in a BTBR T + tf/J mouse model. Previous studies have also shown that resveratrol could reverse the imbalance of Th17/Treg through the mechanism of inhibiting the AhR pathway to achieve the purpose of treating ITP. The Notch signal was involved in Th17 cell differentiation and function, and its inactivation could reverse Th17/Treg imbalance in ITP patients. Notably, the effect of resveratrol on Notch1 signaling is conf licting, that is, resveratrol can enhance or inhibit Notch1 in a cell type-dependent manner. Studies have shown that the Notch signal could downregulate the expression of Foxp3, which inhibited Treg cell differentiation and promoted the occurrence and development of allergic rhinitis. Moreover, proinf lammatory mediators and Notch-1 signaling were proven to be associated
 - 10.1155/2022/7138756: within 1 hour after infection in vitro, resveratrol showed potent anti-HSV activity, and the effect decreases and even disappears as time goes on . Resveratrol suppresses HSV through activation of NF-κB within the nucleus in Vero cells and expressions of essential immediate-early, early, and late HSV genes and synthesis of viral DNA . Resveratrol regulated HSV-2 infection by increasing histone acetylation .
 - 10.2478/mjfst-2022-0005: research, concluded that the grape variety used for wine production is particularly important for determining the biological activity of resveratrol. They studied the effect of H 2 O 2 on the yeast Saccharomyces cerevisiae, which was cultivated in an environment without the presence of wine and with the presence of wine. The yeast in the presence of wine showed less damage.According to some publications, resveratrol acts as an antioxidant and antimutagen. Based on an experiment in which wine was produced in a conventional manner, by prolonged maceration and with the addition of oenological enzymes, it was found that the vinification method does not have a significant effect on the antioxidant properties of wine. None of these methods showed an increased value of antioxidant activity. In contrast to wine obtained by classical maceration and with the addition of oenological enzymes, the content of trans-piceid in wine obtained by prolonged maceration was reduced .A study by monitored the effect of wine drying and the addition of maltodextrin dextrose equivalent on antioxidant activity. A slight decrease was observed during storage, which was amplified by higher temperature and lower water activity.Resveratrol also inhibits the enzymatic activity of both forms of cyclooxygenase, reducing the risk of many cancers. It mediates anti-inflammatory effects and inhibits cyclooxygenase and hydroperoxidase functions (antipromoting activity), and it induces promyelocytic leukaemia cell differentiation (antiprogressive activity) . Resveratrol has the antiproliferative effects of inducing apoptosis in cell lines of various origins, such as leukaemia and cancer of the breast, prostate, colon, and pancreas, as well as head and neck cancers. It induces Fas-dependent apoptosis in some cell lines and Fas-independent apoptosis in others .Research studies show that drinking a glass of red wine a day can reduce the risk of prostate cancer by up to half, and that the protective effect appears to be strongest against the most aggressive
```
